@@ -15,3 +15,6 @@ index_weibo_headers = {
 }
  
 
+headers = {
+    "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/79.0.3945.88 Safari/537.36",
+}
\ No newline at end of file
